---
title: <span class="badge builder"></span> CellValues
---
# <span class="badge builder"></span> CellValues

## Constructor

```python
CellValues()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.CellValues
```

### <span class="badge object-method"></span> decimals

Controls the number of decimals for cell values

```python
def decimals(decimals: float) -> typing.Self
```

### <span class="badge object-method"></span> unit

Controls the cell value unit

```python
def unit(unit: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [CellValues](./object-CellValues.md)
